{% load i18n %}
<html>
<link href="{{ REMOTE_STATIC_URL }}v3/bk/css/bk.css" rel="stylesheet">
<div class="king-exception-box king-500-page">
    <img src="{{ REMOTE_STATIC_URL }}v3/components/exception_500/images/expre_500.png">
    <h1>{% trans '系统出现异常' %}</h1>
    <p>{% trans '请记录下错误场景并及时与开发人员联系' %}</p>
</div>
</html>