{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}{{ title }} | {% trans '管理' %}{% endblock %}

{% block branding %}
<h1 id="site-name">{% trans '管理' %}</h1>
{% endblock %}

{% block userlinks %}
{% endblock %}