<!DOCTYPE html>
<html>
    <head>
        <link rel="icon" href="/static/images/favicon.ico" type="image/x-icon" />
        <meta charset="utf-8">
        <title> index </title>
    <link href="{{BK_STATIC_URL}}/assets/css/app.2a8d678.css" rel="stylesheet"></head>
    <body>
        <div id="app"></div>
        <script>
            var SITE_URL = '{{SITE_URL}}'
            var BK_STATIC_URL = '{{BK_STATIC_URL}}/'
            var REMOTE_STATIC_URL = ''
        </script>
    <script type="text/javascript" src="{{BK_STATIC_URL}}/assets/js/runtime.149c6eb.js"></script><script type="text/javascript" src="{{BK_STATIC_URL}}/assets/js/vue-lib.b43235d.js"></script><script type="text/javascript" src="{{BK_STATIC_URL}}/assets/js/app.d4e4c1b.js"></script></body>
</html>
