{% load i18n %}
<html>
    <link href="{{ REMOTE_STATIC_URL }}v3/bk/css/bk.css" rel="stylesheet">
    <div class="king-exception-box king-403-page">
        <img src="{{ REMOTE_STATIC_URL }}v3/components/exception_403/images/expre_403.png">
        <h1>{% trans '系统权限不足' %}</h1>
        <p>{% trans '你的角色所拥有的权限不足' %}</p>
    </div>
</html>